@@ -14,7 +14,7 @@ struct Cli {
 #[derive(Subcommand)]
 enum Commands {
     Iam { action: String },
-    Greet { name: String },
+    Compute { name: String },
 }
 
 #[tokio::main]
@@ -26,23 +26,30 @@ async fn main() {
     let gcp: GcpConfig = serde_json::from_reader(reader).unwrap();
     match cli.command {
         Commands::Iam { action } => {
-            if action == "create".to_string() {
+            if action == "setup" {
+                config_set(gcp.project_id.as_str()).await;
                 create_service_account(gcp.service_name.as_str()).await;
-            } else if action == "create-key" {
                 create_service_account_key(gcp.service_name.as_str(), gcp.project_id.as_str())
                     .await;
-            } else if action == "roles" {
-                add_roles().await;
+                add_roles(gcp.service_name.as_str(), gcp.project_id.as_str()).await;
             } else {
-                println!("no command with '{}'", action);
+                println!("no command!");
             }
         }
-        Commands::Greet { name } => {
+        Commands::Compute { name } => {
             println!("hello, {}", name);
         }
     }
 }
 
+async fn config_set(project_id: &str) {
+    let output = Command::new("gcloud")
+        .args(&["config", "set", "project", project_id])
+        .output()
+        .await;
+    println!("output = {:?}", output);
+}
+
 async fn create_service_account(service_name: &str) {
     let description = String::from("--description='") + service_name + " Service Account'";
     let display_name = String::from("--display-name=") + service_name;
@@ -78,7 +85,7 @@ async fn create_service_account_key(service_name: &str, project_id: &str) {
     println!("output = {:?}", output);
 }
 
-async fn add_roles() {
+async fn add_roles(service_name: &str, project_id: &str) {
     let roles = [
         "roles/cloudsql.editor",
         "roles/containerregistry.ServiceAgent",
@@ -94,13 +101,11 @@ async fn add_roles() {
         "roles/cloudtranslate.admin",
     ];
     for role in roles {
-        add_service_account_role(role).await;
+        add_service_account_role(service_name, project_id, role).await;
     }
 }
 
-async fn add_service_account_role(role_arg: &str) {
-    let service_name = "epic-gcu";
-    let project_id = "degitana-app";
+async fn add_service_account_role(service_name: &str, project_id: &str, role_arg: &str) {
     let member = String::from("--member=serviceAccount:")
         + service_name
         + "@"
